# Copyright (C) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE in project root for information.

#' Spark ML -- JSONOutputParser
#'
#' 
#' @param dataType format to parse the column to
#' @param inputCol The name of the input column
#' @param outputCol The name of the output column
#' @param postProcessor optional transformation to postprocess json output
#' @export
ml_jsonoutput_parser <- function(x, dataType=NULL, inputCol=NULL, outputCol=NULL, postProcessor=NULL)
{
  if (unfit.model) {
    sc <- x
  } else {
    df <- spark_dataframe(x)
    sc <- spark_connection(df)
  }
  env <- new.env(parent = emptyenv())

  env$model <- "com.microsoft.ml.spark.JSONOutputParser"
  mod <- invoke_new(sc, env$model)

  mod_parameterized <- mod %>%
    invoke("setDataType", dataType) %>%
    invoke("setInputCol", inputCol) %>%
    invoke("setOutputCol", outputCol) %>%
    invoke("setPostProcessor", postProcessor)

  transformed <- invoke(mod_parameterized, "transform", df)

  sdf_register(transformed)
}
